
```{r, include=FALSE}
library(circlize)
library(ComplexHeatmap)
library(corrplot)
library(dplyr)
library(EnhancedVolcano)
library(factoextra)
library(FactoMineR)
library(genefilter)     
library(ggplot2)
library(ggpubr)
library(ggrepel)
library(ggsci)
library(gmodels)
library(gplots)
library(hexbin)
library(limma)
library(matrixStats)
library(RColorBrewer)
library(reshape2)
library(tableone)
library(tidyverse)
library(VennDiagram)

```



```{r}
getwd()
rawdata <- read.delim("/path/to/GSE58095_non-normalized.txt.gz", row.names = 1, skip = 4)
head(rawdata)
data <- rawdata[, grep("SAMPLE", colnames(rawdata))]
head(data)


```

## Normalization by median

```{r}

param <- 50   
out_f <- "GSE58095_normalized_median.txt"

tmp_median <- apply(data, 2, median, na.rm=TRUE)/path/to/
data2 <- sweep(data, 2, param/tmp_median, "*")
data2                                   
apply(data2, 2, median)                

write.table(data2, out_f, sep="\t", append=F, quote=F, row.names=T)

```



## Normalization by Z score

```{r}

in_f <- "GSE58095_normalized_median.txt"              
out_f <- "GSE58095_normalized_median_Zscore.txt"                 

data <- read.table(in_f, header=TRUE, row.names=1, sep="\t", quote="")

data.z <- scale(data)                  
data.z                                 
apply(data.z, 2, mean)              


write.table(data.z, out_f, sep="\t", append=F, quote=F, row.names=T)
```


## Filtering out

```{r}
in_f <- "GSE58095_normalized_median_Zscore.txt"             
out_f <- "GSE58095_normalized_median_Zscore_filtered_EX20.txt"                
param <- 0.2                          


data <- read.table(in_f, header=TRUE, row.names=1, sep="\t", quote="")
dim(data)

ave <- rowMeans(data)                  
hoge <- quantile(ave, probs=param)     
obj <- (ave >= hoge)                  
data <- data[obj,]                    
dim(data)                              

write.table(data, out_f, sep="\t", append=F, quote=F, row.names=T)
```


## Filtering out

```{r}
in_f <- "GSE58095_normalized_median_Zscore_filtered_EX20.txt"              
out_f <- "GSE58095_normalized_median_Zscore_filtered_EX20_CV75.txt"                  
param <- 0.75                           

data <- read.table(in_f, header=TRUE, row.names=1, sep="\t", quote="")


hoge <- apply(data,1,sd)/apply(data,1,mean)
hoge2 <- quantile(hoge, probs=param) 
obj <- (hoge >= hoge2)                
data <- data[obj,]                    
summary(hoge)                         
dim(data)                           
write.table(data, out_f, sep="\t", append=F, quote=F, row.names=T)

```

```{r}
in_f <- "GSE58095_normalized_median_Zscore_filtered_EX20_CV75.txt"              


data <- read.table(in_f, header=TRUE, row.names=1, sep="\t", quote="")
data

anno1 <- read.delim("/path/to/GSE58095_RAW/GPL10558_HumanHT-12_V4_0_R1_15002873_B.txt", row.names = NULL)
anno1 

sampleInfo <- read.delim("/path/to/GSE58095_all_sample_annotatiions.txt.gz", header = TRUE, skip=4)
sampleInfo



```

```{r}

in_f <- "GSE58095_normalized_median_Zscore_filtered_EX20_CV75.txt"              
out_f <- "GSE58095_normalized_median_Zscore_filtered_EX20_CV75_DEGs.txt"  

data <- t(read.table(in_f, header=TRUE, row.names=1, sep="\t", quote=""))
data


sampleInfo <- read.delim("/path/to/GSE58095_all_sample_annotatiions.txt.gz", header = TRUE, skip=4)
sampleInfo

data2 <-merge(sampleInfo,data, by.x = "Sample.name", by.y = "row.names")

rownames(data2) <- data2$Sample.name
# Take a quick look at what is in the data set:
dim(data2);

data_Control <- subset(data2, Characteristics..Group=="Control")
data_None <- subset(data2, characteristics..Antibody.group=="None")
data_ACA <- subset(data2, characteristics..Antibody.group=="ACA")
data_RNP <- subset(data2, characteristics..Antibody.group=="RNP")
data_ATA <- subset(data2, characteristics..Antibody.group=="ATA")
data_RNAP <- subset(data2, characteristics..Antibody.group=="RNAP")

data3 <- rbind(data_Control, data_None, data_ACA, data_RNP, data_ATA, data_RNAP)

data3[1:nrow(data_Control), ]$characteristics..Antibody.group <- "Control"

data4 = data3[,-c(1:20)];

cl <- as.factor(data3$characteristics..Antibody.group)
cl <- as.factor(ifelse(is.na(cl), "Control", as.character(cl)))

t.data4 <- t(data4)


antibody = cl
ha1 = HeatmapAnnotation(antibody = antibody,col = list(antibody = c("ACA"="red","ATA"="gold","None"="green","RNAP"="blue","RNP"="purple","Control"="grey")),annotation_name_side = "left",simple_anno_size = unit(3, "mm"),show_annotation_name = TRUE)
status <- data3$Characteristics..Group
ha2 = HeatmapAnnotation(status = status,col = list(status= c("SSc"="red","Control"="grey")),annotation_name_side = "left",simple_anno_size = unit(3, "mm"),show_annotation_name = TRUE)
cl2 <- as.factor(data3$Characteristics..Diffuse.vs.limited)
cl2 <- as.factor(ifelse(cl2=="", "Control", as.character(cl2)))
disease_type <- cl2


res.pca <- prcomp(data3[,-c(1:20)], scale = FALSE)
p<- fviz_pca_ind(res.pca, title = "PCA",
                 col.ind = cl, # color by groups
                 addEllipses = TRUE, # Concentration ellipses
                 ellipse.level=0.95,ellipse.type = "confidence",
                 legend.title = "Groups",
                 repel = TRUE, 
                 invisible = "quali", geom.ind="point",pointsize=2) + scale_color_manual(values=c("red","gold","black","forestgreen","blue","purple"))+ scale_fill_manual(values=c("red","gold","grey","green","blue","purple"))
plot(p)
p<- fviz_pca_ind(res.pca, title = "PCA",
                 col.ind = cl2, # color by groups
                 addEllipses = TRUE, # Concentration ellipses
                 ellipse.level=0.95,ellipse.type = "confidence",
                 legend.title = "Groups",
                 repel = TRUE, 
                 invisible = "quali", geom.ind="point",pointsize=2) + scale_color_manual(values=c("black","brown","red"))+ scale_fill_manual(values=c("grey","brown","pink"))
plot(p)

ha3 = HeatmapAnnotation(disease_type = disease_type,col = list(disease_type= c("Dif"="brown","Lim"="pink","Control"="grey")),annotation_name_side = "left",simple_anno_size = unit(3, "mm"),show_annotation_name = TRUE)

#ha <- c(ha1, ha2, ha3)
ha <- c(ha1, ha3)
ht_list = Heatmap(t(scale(data3[,-c(1:20)])),
                  column_split = data3$characteristics..Antibody.group,
                  col = colorRamp2(c(-1.5, 0, 1.5), c("purple", "black", "yellow")), 
                  name = "scaled_expr", 
                  column_title = ("Gene Expression Profile in skin"),
                  show_column_names = FALSE, width = unit(8, "cm"),show_row_names = FALSE,
                  heatmap_legend_param = list(title = "Scaled expr"),
                  cluster_columns = TRUE,cluster_rows = TRUE,
                  clustering_method_rows = "ward.D2", clustering_distance_rows = "euclidean", 
                  top_annotation = ha) 
draw(ht_list)
ht_list = Heatmap(t(scale(data3[,-c(1:20)])),
                  #column_split = data3$characteristics..Antibody.group,
                  col = colorRamp2(c(-1.5, 0, 1.5), c("purple", "black", "yellow")), 
                  name = "scaled_expr", 
                  column_title = ("Gene Expression Profile in skin"),
                  show_column_names = FALSE, width = unit(8, "cm"),show_row_names = FALSE,
                  heatmap_legend_param = list(title = "Scaled expr"),
                  cluster_columns = TRUE,cluster_rows = TRUE,
                  clustering_method_rows = "ward.D2", clustering_distance_rows = "euclidean", 
                  top_annotation = ha) 
draw(ht_list)


design <- model.matrix(~ 0 + cl)       
colnames(design) <- levels(cl)        
fit <- lmFit(t.data4, design)             
contrast <- makeContrasts(             
  NonevsControl = None - Control, 
  ACAvsControl = ACA - Control, 
  RNPvsControl = RNP - Control,                 
  RNAPvsControl = RNAP - Control,                 
  ATAvsControl = ATA - Control,                 
  levels = design)                   
fit2 <- contrasts.fit(fit, contrast)   
out <- eBayes(fit2)                   
coef <- out$coefficients
colnames(coef) <- c("NonevsControl_coef", "ACAvsControl_coef",  "RNPvsControl_coef",  "RNAPvsControl_coef", "ATAvsControl_coef")
p.value <- out$p.value                 
colnames(p.value) <- c("NonevsControl_p.value", "ACAvsControl_p.value",  "RNPvsControl_p.value",  "RNAPvsControl_p.value", "ATAvsControl_p.value")
q.value <- apply(p.value, MARGIN=2, p.adjust, method="fdr")
colnames(q.value) <- c("NonevsControl_q.value", "ACAvsControl_q.value",  "RNPvsControl_q.value",  "RNAPvsControl_q.value", "ATAvsControl_q.value")
ranking <- apply(p.value, MARGIN=2, rank)
colnames(ranking) <- c("NonevsControl_ranking", "ACAvsControl_ranking",  "RNPvsControl_ranking",  "RNAPvsControl_ranking", "ATAvsControl_ranking")

#ファイルに保存
tmp <- cbind(t.data4, coef, p.value, q.value, ranking)
write.table(tmp, out_f, sep="\t", append=F, quote=F, row.names=T)


```


```{r}
#apply k-means partitioning.
ht = Heatmap(t(scale(data3[,-c(1:20)])),
             #column_split = data3$characteristics..Antibody.group,
             col = colorRamp2(c(-1.5, 0, 1.5), c("purple", "black", "yellow")), 
             name = "scaled_expr", 
             column_title = ("Gene Expression Profile in skin"),
             show_column_names = FALSE, width = unit(8, "cm"),show_row_names = FALSE,
             heatmap_legend_param = list(title = "Scaled expr"),
             cluster_columns = TRUE,cluster_rows = TRUE,
             clustering_method_rows = "ward.D2", clustering_distance_rows = "euclidean", 
             top_annotation = ha, 
             row_km = 3, column_km = 3
)
draw(ht)
r.dend <- row_dend(ht)  #Extract row dendrogram
rcl.list <- row_order(ht)  #Extract clusters (output is a list)

mat <- t(scale(data3[,-c(1:20)]))

for (i in 1:length(row_order(ht))){
  if (i == 1) {
    clu <- t(t(row.names(mat[row_order(ht)[[i]],])))
    out <- cbind(clu, paste("cluster", i, sep=""))
    colnames(out) <- c("GeneID", "Cluster")
  } else {
    clu <- t(t(row.names(mat[row_order(ht)[[i]],])))
    clu <- cbind(clu, paste("cluster", i, sep=""))
    out <- rbind(out, clu)
  }
}

out #check
anno1 <- read.delim("/path/to/GSE58095_RAW/GPL10558_HumanHT-12_V4_0_R1_15002873_B.txt", row.names = NULL)
out2 <- merge(as.data.frame(out), anno1, by.x = "GeneID", by.y = "Probe_Id")
out2
table(out2$Cluster)
write.table(out2, file= "gene_clusters_SSc_GENISOS.txt", sep="\t", quote=F, row.names=FALSE) #export
```


```{r}


in_f <- "GSE58095_normalized_median_Zscore_filtered_EX20_CV75_DEGs.txt"              
out_f <- "GSE58095_normalized_median_Zscore_filtered_EX20_CV75_DEGs_annotated.txt" 

#入力ファイルの読み込み
data <- read.table(in_f, header=TRUE, row.names=1, sep="\t", quote="") 

anno1 <- read.delim("/path/to/GSE58095_RAW/GPL10558_HumanHT-12_V4_0_R1_15002873_B.txt", row.names = NULL)
data2 <- merge(data, anno1, by.x = "row.names", by.y = "Probe_Id")

gene = data2 

NonevsControl <- data.frame(gene[gene$NonevsControl_q.value < 0.05, ]$ILMN_Gene, gene[gene$NonevsControl_q.value < 0.05, ]$Row.names, gene[gene$NonevsControl_q.value < 0.05, ]$NonevsControl_coef, gene[gene$NonevsControl_q.value < 0.05, ]$NonevsControl_q.value)
colnames(NonevsControl) <- c("ILMN_Gene", "Probe_ID", "logFC_NonevsControl", "q.value_BH")
write.csv(NonevsControl,  "NonevsControl.csv")
gene2 <- read.csv("NonevsControl.csv", header = TRUE)

write.table(as.character(gene2[gene2$logFC_NonevsControl > log2(1.5/1), ]$ILMN_Gene), "NonevsControl_FC>1.5_q.value<0.05.txt",row.names=F,col.names=F, quote=F)
write.table(as.character(gene2[gene2$logFC_NonevsControl < log2(1/1.5), ]$ILMN_Gene), "NonevsControl_FC<0.667_q.value<0.05.txt",row.names=F,col.names=F, quote=F)

ACAvsControl <- data.frame(gene[gene$ACAvsControl_q.value < 0.05, ]$ILMN_Gene, gene[gene$ACAvsControl_q.value < 0.05, ]$Row.names, gene[gene$ACAvsControl_q.value < 0.05, ]$ACAvsControl_coef, gene[gene$ACAvsControl_q.value < 0.05, ]$ACAvsControl_q.value)
colnames(ACAvsControl) <- c("ILMN_Gene", "Probe_ID", "logFC_ACAvsControl", "q.value_BH")
write.csv(ACAvsControl,  "ACAvsControl.csv")
gene2 <- read.csv("ACAvsControl.csv", header = TRUE)

write.table(as.character(gene2[gene2$logFC_ACAvsControl > log2(1.5/1), ]$ILMN_Gene), "ACAvsControl_FC>1.5_q.value<0.05.txt",row.names=F,col.names=F, quote=F)
write.table(as.character(gene2[gene2$logFC_ACAvsControl < log2(1/1.5), ]$ILMN_Gene), "ACAvsControl_FC<0.667_q.value<0.05.txt",row.names=F,col.names=F, quote=F)

RNPvsControl <- data.frame(gene[gene$RNPvsControl_q.value < 0.05, ]$ILMN_Gene, gene[gene$RNPvsControl_q.value < 0.05, ]$Row.names, gene[gene$RNPvsControl_q.value < 0.05, ]$RNPvsControl_coef, gene[gene$RNPvsControl_q.value < 0.05, ]$RNPvsControl_q.value)
colnames(RNPvsControl) <- c("ILMN_Gene", "Probe_ID", "logFC_RNPvsControl", "q.value_BH")
write.csv(RNPvsControl,  "RNPvsControl.csv")
gene2 <- read.csv("RNPvsControl.csv", header = TRUE)

write.table(as.character(gene2[gene2$logFC_RNPvsControl > log2(1.5/1), ]$ILMN_Gene), "RNPvsControl_FC>1.5_q.value<0.05.txt",row.names=F,col.names=F, quote=F)
write.table(as.character(gene2[gene2$logFC_RNPvsControl < log2(1/1.5), ]$ILMN_Gene), "RNPvsControl_FC<0.667_q.value<0.05.txt",row.names=F,col.names=F, quote=F)

RNAPvsControl <- data.frame(gene[gene$RNAPvsControl_q.value < 0.05, ]$ILMN_Gene, gene[gene$RNAPvsControl_q.value < 0.05, ]$Row.names, gene[gene$RNAPvsControl_q.value < 0.05, ]$RNAPvsControl_coef, gene[gene$RNAPvsControl_q.value < 0.05, ]$RNAPvsControl_q.value)
colnames(RNAPvsControl) <- c("ILMN_Gene", "Probe_ID", "logFC_RNAPvsControl", "q.value_BH")
write.csv(RNAPvsControl,  "RNAPvsControl.csv")
gene2 <- read.csv("RNAPvsControl.csv", header = TRUE)

write.table(as.character(gene2[gene2$logFC_RNAPvsControl > log2(1.5/1), ]$ILMN_Gene), "RNAPvsControl_FC>1.5_q.value<0.05.txt",row.names=F,col.names=F, quote=F)
write.table(as.character(gene2[gene2$logFC_RNAPvsControl < log2(1/1.5), ]$ILMN_Gene), "RNAPvsControl_FC<0.667_q.value<0.05.txt",row.names=F,col.names=F, quote=F)

ATAvsControl <- data.frame(gene[gene$ATAvsControl_q.value < 0.05, ]$ILMN_Gene, gene[gene$ATAvsControl_q.value < 0.05, ]$Row.names, gene[gene$ATAvsControl_q.value < 0.05, ]$ATAvsControl_coef, gene[gene$ATAvsControl_q.value < 0.05, ]$ATAvsControl_q.value)
colnames(ATAvsControl) <- c("ILMN_Gene", "Probe_ID", "logFC_ATAvsControl", "q.value_BH")
write.csv(ATAvsControl,  "ATAvsControl.csv")
gene2 <- read.csv("ATAvsControl.csv", header = TRUE)

write.table(as.character(gene2[gene2$logFC_ATAvsControl > log2(1.5/1), ]$ILMN_Gene), "ATAvsControl_FC>1.5_q.value<0.05.txt",row.names=F,col.names=F, quote=F)
write.table(as.character(gene2[gene2$logFC_ATAvsControl < log2(1/1.5), ]$ILMN_Gene), "ATAvsControl_FC<0.667_q.value<0.05.txt",row.names=F,col.names=F, quote=F)


```

```{r}
in_f <- "GSE58095_normalized_median_Zscore_filtered_EX20_CV75_DEGs.txt"              


data <- read.table(in_f, header=TRUE, row.names=1, sep="\t", quote="") 

anno1 <- read.delim("/path/to/GSE58095_RAW/GPL10558_HumanHT-12_V4_0_R1_15002873_B.txt", row.names = NULL)
data2 <- merge(data, anno1, by.x = "row.names", by.y = "Probe_Id")


# Make a basic ggplot2 object
vol <- ggplot(data2, aes(x = NonevsControl_coef, y = -log10(NonevsControl_q.value), labels=ILMN_Gene))
sig_up <- data2[ which(data2$NonevsControl_coef > log2(1.5/1) & data2$NonevsControl_q.value < 0.05),]
sig_down <- data2[ which(data2$NonevsControl_coef < log2(1/1.5) & data2$NonevsControl_q.value < 0.05),]
sig_up2 <- data2[ which(data2$NonevsControl_coef > log2(1.5/1) & data2$NonevsControl_q.value > 0.05),]
sig_down2 <- data2[ which(data2$NonevsControl_coef < log2(1/1.5) & data2$NonevsControl_q.value > 0.05),]
sig_up3 <- data2[ which(data2$NonevsControl_coef > log2(1) & data2$NonevsControl_q.value < 0.05),]
sig_down3 <- data2[ which(data2$NonevsControl_coef < log2(1) & data2$NonevsControl_q.value < 0.05),]
insig <- data2[ which(data2$NonevsControl_coef < log2(1.5/1) & data2$NonevsControl_coef > log2(1/1.5) & data2$NonevsControl_q.value > 0.05),]
sig_up <- sig_up[order(sig_up$NonevsControl_q.value),]
sig_down <- sig_down[order(sig_down$NonevsControl_q.value),]

# inserting mnaual colors as per color pallette and more
vol +   
  ggtitle(label = "Volcano Plot", subtitle = "NonevsControl") +
  geom_point(data = sig_up, col="red", alpha = 1, size = 1) +
  geom_point(data = sig_down, col="blue", alpha = 1, size = 1) +
  geom_point(data = sig_up2, col="pink", alpha = 0.5, size = 1) +
  geom_point(data = sig_down2, col="skyblue", alpha = 0.5, size = 1) +
  geom_point(data = sig_up3, col="pink", alpha = 0.5, size = 1) +
  geom_point(data = sig_down3, col="skyblue", alpha = 0.5, size = 1) +
  geom_point(data = insig, col="grey", alpha = 0.5, size = 1) +
  ggrepel::geom_text_repel(data=sig_up [1:10, ], ggplot2::aes(label=sig_up[1:10, ]$Symbol)) +
  ggrepel::geom_text_repel(data=sig_down [1:10, ], ggplot2::aes(label=sig_down[1:10, ]$Symbol)) +
  theme_bw(base_size = 14) + 
  theme(legend.position = "right",axis.text.x = element_text(size=15),axis.text.y = element_text(size=15)) + 
  xlab(expression(log[2]("None" / "Control"))) + 
  ylab(expression(-log[10]("FDR"))) +
  geom_hline(yintercept = -log10(0.05), colour="#990000", linetype="dashed") + geom_vline(xintercept = log2(1.5/1), colour="#990000", linetype="dashed") + geom_vline(xintercept = log2(1/1.5), colour="#990000", linetype="dashed") 


# Make a basic ggplot2 object
vol <- ggplot(data2, aes(x = ACAvsControl_coef, y = -log10(ACAvsControl_q.value), labels=ILMN_Gene))
sig_up <- data2[ which(data2$ACAvsControl_coef > log2(1.5/1) & data2$ACAvsControl_q.value < 0.05),]
sig_down <- data2[ which(data2$ACAvsControl_coef < log2(1/1.5) & data2$ACAvsControl_q.value < 0.05),]
sig_up2 <- data2[ which(data2$ACAvsControl_coef > log2(1.5/1) & data2$ACAvsControl_q.value > 0.05),]
sig_down2 <- data2[ which(data2$ACAvsControl_coef < log2(1/1.5) & data2$ACAvsControl_q.value > 0.05),]
sig_up3 <- data2[ which(data2$ACAvsControl_coef > log2(1) & data2$ACAvsControl_q.value < 0.05),]
sig_down3 <- data2[ which(data2$ACAvsControl_coef < log2(1) & data2$ACAvsControl_q.value < 0.05),]
insig <- data2[ which(data2$ACAvsControl_coef < log2(1.5/1) & data2$ACAvsControl_coef > log2(1/1.5) & data2$ACAvsControl_q.value > 0.05),]
sig_up <- sig_up[order(sig_up$ACAvsControl_q.value),]
sig_down <- sig_down[order(sig_down$ACAvsControl_q.value),]

# inserting mnaual colors as per color pallette and more
vol +   
  ggtitle(label = "Volcano Plot", subtitle = "ACAvsControl") +
  geom_point(data = sig_up, col="red", alpha = 1, size = 1) +
  geom_point(data = sig_down, col="blue", alpha = 1, size = 1) +
  geom_point(data = sig_up2, col="pink", alpha = 0.5, size = 1) +
  geom_point(data = sig_down2, col="skyblue", alpha = 0.5, size = 1) +
  geom_point(data = sig_up3, col="pink", alpha = 0.5, size = 1) +
  geom_point(data = sig_down3, col="skyblue", alpha = 0.5, size = 1) +
  geom_point(data = insig, col="grey", alpha = 0.5, size = 1) +
  ggrepel::geom_text_repel(data=sig_up [1:10, ], ggplot2::aes(label=sig_up[1:10, ]$Symbol)) +
  ggrepel::geom_text_repel(data=sig_down [1:10, ], ggplot2::aes(label=sig_down[1:10, ]$Symbol)) +
  theme_bw(base_size = 14) + 
  theme(legend.position = "right",axis.text.x = element_text(size=15),axis.text.y = element_text(size=15)) + 
  xlab(expression(log[2]("ACA" / "Control"))) + 
  ylab(expression(-log[10]("FDR"))) +
  geom_hline(yintercept = -log10(0.05), colour="#990000", linetype="dashed") + geom_vline(xintercept = log2(1.5/1), colour="#990000", linetype="dashed") + geom_vline(xintercept = log2(1/1.5), colour="#990000", linetype="dashed") 

# Make a basic ggplot2 object
vol <- ggplot(data2, aes(x = RNPvsControl_coef, y = -log10(RNPvsControl_q.value), labels=ILMN_Gene))
sig_up <- data2[ which(data2$RNPvsControl_coef > log2(1.5/1) & data2$RNPvsControl_q.value < 0.05),]
sig_down <- data2[ which(data2$RNPvsControl_coef < log2(1/1.5) & data2$RNPvsControl_q.value < 0.05),]
sig_up2 <- data2[ which(data2$RNPvsControl_coef > log2(1.5/1) & data2$RNPvsControl_q.value > 0.05),]
sig_down2 <- data2[ which(data2$RNPvsControl_coef < log2(1/1.5) & data2$RNPvsControl_q.value > 0.05),]
sig_up3 <- data2[ which(data2$RNPvsControl_coef > log2(1) & data2$RNPvsControl_q.value < 0.05),]
sig_down3 <- data2[ which(data2$RNPvsControl_coef < log2(1) & data2$RNPvsControl_q.value < 0.05),]
insig <- data2[ which(data2$RNPvsControl_coef < log2(1.5/1) & data2$RNPvsControl_coef > log2(1/1.5) & data2$RNPvsControl_q.value > 0.05),]
sig_up <- sig_up[order(sig_up$RNPvsControl_q.value),]
sig_down <- sig_down[order(sig_down$RNPvsControl_q.value),]

# inserting mnaual colors as per color pallette and more
vol +   
  ggtitle(label = "Volcano Plot", subtitle = "RNPvsControl") +
  geom_point(data = sig_up, col="red", alpha = 1, size = 1) +
  geom_point(data = sig_down, col="blue", alpha = 1, size = 1) +
  geom_point(data = sig_up2, col="pink", alpha = 0.5, size = 1) +
  geom_point(data = sig_down2, col="skyblue", alpha = 0.5, size = 1) +
  geom_point(data = sig_up3, col="pink", alpha = 0.5, size = 1) +
  geom_point(data = sig_down3, col="skyblue", alpha = 0.5, size = 1) +
  geom_point(data = insig, col="grey", alpha = 0.5, size = 1) +
  ggrepel::geom_text_repel(data=sig_up [1:10, ], ggplot2::aes(label=sig_up[1:10, ]$Symbol)) +
  ggrepel::geom_text_repel(data=sig_down [1:10, ], ggplot2::aes(label=sig_down[1:10, ]$Symbol)) +
  theme_bw(base_size = 14) + 
  theme(legend.position = "right",axis.text.x = element_text(size=15),axis.text.y = element_text(size=15)) + 
  xlab(expression(log[2]("RNP" / "Control"))) + 
  ylab(expression(-log[10]("FDR"))) +
  geom_hline(yintercept = -log10(0.05), colour="#990000", linetype="dashed") + geom_vline(xintercept = log2(1.5/1), colour="#990000", linetype="dashed") + geom_vline(xintercept = log2(1/1.5), colour="#990000", linetype="dashed") 


# Make a basic ggplot2 object
vol <- ggplot(data2, aes(x = RNAPvsControl_coef, y = -log10(RNAPvsControl_q.value), labels=ILMN_Gene))
sig_up <- data2[ which(data2$RNAPvsControl_coef > log2(1.5/1) & data2$RNAPvsControl_q.value < 0.05),]
sig_down <- data2[ which(data2$RNAPvsControl_coef < log2(1/1.5) & data2$RNAPvsControl_q.value < 0.05),]
sig_up2 <- data2[ which(data2$RNAPvsControl_coef > log2(1.5/1) & data2$RNAPvsControl_q.value > 0.05),]
sig_down2 <- data2[ which(data2$RNAPvsControl_coef < log2(1/1.5) & data2$RNAPvsControl_q.value > 0.05),]
sig_up3 <- data2[ which(data2$RNAPvsControl_coef > log2(1) & data2$RNAPvsControl_q.value < 0.05),]
sig_down3 <- data2[ which(data2$RNAPvsControl_coef < log2(1) & data2$RNAPvsControl_q.value < 0.05),]
insig <- data2[ which(data2$RNAPvsControl_coef < log2(1.5/1) & data2$RNAPvsControl_coef > log2(1/1.5) & data2$RNAPvsControl_q.value > 0.05),]
sig_up <- sig_up[order(sig_up$RNAPvsControl_q.value),]
sig_down <- sig_down[order(sig_down$RNAPvsControl_q.value),]

# inserting mnaual colors as per color pallette and more
vol +   
  ggtitle(label = "Volcano Plot", subtitle = "RNAPvsControl") +
  geom_point(data = sig_up, col="red", alpha = 1, size = 1) +
  geom_point(data = sig_down, col="blue", alpha = 1, size = 1) +
  geom_point(data = sig_up2, col="pink", alpha = 0.5, size = 1) +
  geom_point(data = sig_down2, col="skyblue", alpha = 0.5, size = 1) +
  geom_point(data = sig_up3, col="pink", alpha = 0.5, size = 1) +
  geom_point(data = sig_down3, col="skyblue", alpha = 0.5, size = 1) +
  geom_point(data = insig, col="grey", alpha = 0.5, size = 1) +
  ggrepel::geom_text_repel(data=sig_up [1:10, ], ggplot2::aes(label=sig_up[1:10, ]$Symbol)) +
  ggrepel::geom_text_repel(data=sig_down [1:10, ], ggplot2::aes(label=sig_down[1:10, ]$Symbol)) +
  theme_bw(base_size = 14) + 
  theme(legend.position = "right",axis.text.x = element_text(size=15),axis.text.y = element_text(size=15)) + 
  xlab(expression(log[2]("RNAP" / "Control"))) + 
  ylab(expression(-log[10]("FDR"))) +
  geom_hline(yintercept = -log10(0.05), colour="#990000", linetype="dashed") + geom_vline(xintercept = log2(1.5/1), colour="#990000", linetype="dashed") + geom_vline(xintercept = log2(1/1.5), colour="#990000", linetype="dashed") 


# Make a basic ggplot2 object
vol <- ggplot(data2, aes(x = ATAvsControl_coef, y = -log10(ATAvsControl_q.value), labels=ILMN_Gene))
sig_up <- data2[ which(data2$ATAvsControl_coef > log2(1.5/1) & data2$ATAvsControl_q.value < 0.05),]
sig_down <- data2[ which(data2$ATAvsControl_coef < log2(1/1.5) & data2$ATAvsControl_q.value < 0.05),]
sig_up2 <- data2[ which(data2$ATAvsControl_coef > log2(1.5/1) & data2$ATAvsControl_q.value > 0.05),]
sig_down2 <- data2[ which(data2$ATAvsControl_coef < log2(1/1.5) & data2$ATAvsControl_q.value > 0.05),]
sig_up3 <- data2[ which(data2$ATAvsControl_coef > log2(1) & data2$ATAvsControl_q.value < 0.05),]
sig_down3 <- data2[ which(data2$ATAvsControl_coef < log2(1) & data2$ATAvsControl_q.value < 0.05),]
insig <- data2[ which(data2$ATAvsControl_coef < log2(1.5/1) & data2$ATAvsControl_coef > log2(1/1.5) & data2$ATAvsControl_q.value > 0.05),]
sig_up <- sig_up[order(sig_up$ATAvsControl_q.value),]
sig_down <- sig_down[order(sig_down$ATAvsControl_q.value),]

# inserting mnaual colors as per color pallette and more
vol +   
  ggtitle(label = "Volcano Plot", subtitle = "ATAvsControl") +
  geom_point(data = sig_up, col="red", alpha = 1, size = 1) +
  geom_point(data = sig_down, col="blue", alpha = 1, size = 1) +
  geom_point(data = sig_up2, col="pink", alpha = 0.5, size = 1) +
  geom_point(data = sig_down2, col="skyblue", alpha = 0.5, size = 1) +
  geom_point(data = sig_up3, col="pink", alpha = 0.5, size = 1) +
  geom_point(data = sig_down3, col="skyblue", alpha = 0.5, size = 1) +
  geom_point(data = insig, col="grey", alpha = 0.5, size = 1) +
  ggrepel::geom_text_repel(data=sig_up [1:10, ], ggplot2::aes(label=sig_up[1:10, ]$Symbol)) +
  ggrepel::geom_text_repel(data=sig_down [1:10, ], ggplot2::aes(label=sig_down[1:10, ]$Symbol)) +
  theme_bw(base_size = 14) + 
  theme(legend.position = "right",axis.text.x = element_text(size=15),axis.text.y = element_text(size=15)) + 
  xlab(expression(log[2]("ATA" / "Control"))) + 
  ylab(expression(-log[10]("FDR"))) +
  geom_hline(yintercept = -log10(0.05), colour="#990000", linetype="dashed") + geom_vline(xintercept = log2(1.5/1), colour="#990000", linetype="dashed") + geom_vline(xintercept = log2(1/1.5), colour="#990000", linetype="dashed") 


```


```{r}
# Chart
gene <-  read.table("ACAvsControl_FC>1.5_q.value<0.05.txt",header=F)
prot2 <- unique(gene$V1)
gene <-  read.table("RNPvsControl_FC>1.5_q.value<0.05.txt",header=F)
prot3 <- unique(gene$V1)
gene <-  read.table("RNAPvsControl_FC>1.5_q.value<0.05.txt",header=F)
prot4 <- unique(gene$V1)
gene <-  read.table("ATAvsControl_FC>1.5_q.value<0.05.txt",header=F)
prot5 <- unique(gene$V1)

df <- list(ACA = prot2, RNP = prot3, RNAP = prot4, ATA = prot5)
venn(df, simplify=FALSE, small = 1) # with empty groupings
a<-venn(df, show.plot=FALSE)
intersections<-attr(a,"intersections")
print(intersections)
write.table(as.character(intersections$RNAP), "only_RNAP_upDEGs.txt",row.names=F,col.names=F, quote=F)
write.table(as.character(intersections$ATA), "only_ATA_upDEGs.txt",row.names=F,col.names=F, quote=F)
write.table(as.character(intersections$ACA), "only_ACA_upDEGs.txt",row.names=F,col.names=F, quote=F)
write.table(as.character(intersections$RNP), "only_RNP_upDEGs.txt",row.names=F,col.names=F, quote=F)

# Chart
gene <-  read.table("ACAvsControl_FC<0.667_q.value<0.05.txt",header=F)
prot2 <- unique(gene$V1)
#gene <-  read.table("RNPvsControl_FC<0.667_q.value<0.05.txt",header=F)
gene <- NULL
prot3 <- unique(gene$V1)
gene <-  read.table("RNAPvsControl_FC<0.667_q.value<0.05.txt",header=F)
prot4 <- unique(gene$V1)
gene <-  read.table("ATAvsControl_FC<0.667_q.value<0.05.txt",header=F)
prot5 <- unique(gene$V1)

df <- list(ACA = prot2, RNP = prot3, RNAP = prot4, ATA = prot5)
venn(df, simplify=FALSE, small = 1) # with empty groupings
a<-venn(df, show.plot=FALSE)
intersections<-attr(a,"intersections")
print(intersections)
write.table(as.character(intersections$RNAP), "only_RNAP_downDEGs.txt",row.names=F,col.names=F, quote=F)
write.table(as.character(intersections$ATA), "only_ATA_downDEGs.txt",row.names=F,col.names=F, quote=F)
write.table(as.character(intersections$ACA), "only_ACA_downDEGs.txt",row.names=F,col.names=F, quote=F)
write.table(as.character(intersections$RNP), "only_RNP_downDEGs.txt",row.names=F,col.names=F, quote=F)
```
